@@ -3,9 +3,9 @@ from .RPCClient import RPCClient
 from .DobotlinkAdapter import DobotlinkAdapter
 from .Utils import loggers
 from .Magician import MagicianApi
-from .M1 import M1Api
+from .MagicBox import MagicBoxApi
 from .Lite import LiteApi
 
 
 __all__ = ("loggers", "RPCClient", "DobotlinkAdapter", "NetworkError",
-           "MagicianApi", "M1Api", "LiteApi")
+           "MagicianApi", "LiteApi", "MagicBoxApi")
